import DateFnsUtils from "@date-io/date-fns";
import Theme from "@e-group/material/Theme";
import Snackbar, { SnackbarProps } from "@e-group/material-lab/Snackbar";
import AlertDialog from "@e-group/material-module/AlertDialog";
import { withReduxDialog } from "@e-group/redux-modules/dialogs";
import { withReduxSnackbar } from "@e-group/redux-modules/snackbars";
import { MuiPickersUtilsProvider } from "@material-ui/pickers";
import RouterRoot from "components/RouterRoot";
import React from "react";
import { CookiesProvider } from "react-cookie";
import { Provider } from "react-redux";
import { BrowserRouter } from "react-router-dom";
import { store } from "redux/configureAppStore";
import theme from "theme";

export const DIALOG = "globalAlertDialog";
export const SNACKBAR = "globalSnackbar";
const GlobalAlertDialog = withReduxDialog(DIALOG)(AlertDialog);
const GlobalSnackbar = withReduxSnackbar(SNACKBAR)<HTMLDivElement, SnackbarProps>(
  Snackbar
);

function App() {
  return (
    <Provider store={store}>
      <BrowserRouter>
        <CookiesProvider>
          <Theme theme={theme} >
            <MuiPickersUtilsProvider utils={DateFnsUtils}>
              <GlobalAlertDialog />
              <GlobalSnackbar
                anchorOrigin={{
                  vertical: "top",
                  horizontal: "center",
                }}
                autoHideDuration={2000}
              />
              <RouterRoot />
            </MuiPickersUtilsProvider>
          </Theme>
        </CookiesProvider>
      </BrowserRouter>
    </Provider>
  );
}

export default App;
