import Container from "@e-group/material/Container";
import Grid from "@e-group/material/Grid";
import Typography from "@e-group/material/Typography";
import { FC } from "react";
import { useCookies } from "react-cookie";
import { useHistory } from "react-router";
import { EgRouteConfig } from "typings";

interface HomeProps {
  publicRoutes: EgRouteConfig[];
}

const Home: FC<HomeProps> = ({ publicRoutes }) => {
  const history = useHistory();
  const [, setCookie] = useCookies();

  const handleClick = () => {
    setCookie("hasLoginCookie", "true");
    history.push("/me");
  };

  return (
    <Container>
      <Grid container spacing={3}>
        <Grid item xs={12}>
          <Typography variant="h6">react hook form examples</Typography>
          <Grid item xs={12} container spacing={1}>
            {publicRoutes[1]?.routes?.map((el) => (
              <Grid item>
                <button
                  onClick={() => {
                    history.push(el.path as string);
                  }}
                  type="button"
                >
                  {el.breadcrumbName}
                </button>
              </Grid>
            ))}
          </Grid>
        </Grid>
        <Grid item xs={12}>
          <Typography variant="h6">redux examples</Typography>
          <Grid item xs={12} container spacing={1}>
            {publicRoutes[2]?.routes?.map((el) => (
              <Grid item>
                <button
                  onClick={() => {
                    history.push(el.path as string);
                  }}
                  type="button"
                >
                  {el.breadcrumbName}
                </button>
              </Grid>
            ))}
          </Grid>
        </Grid>
        <Grid item xs={12}>
          <Typography variant="h6">Private Pages</Typography>
          <button onClick={handleClick} type="button">
            Enter private page
          </button>
        </Grid>
      </Grid>
    </Container>
  );
};

export default Home;
