import useAxiosApi, { AxiosApi } from "@e-group/hooks/useAxiosApi";
import getDeviceInfo from "@e-group/utils/getDeviceInfo";
import { AxiosError } from "axios";
import { useCallback } from "react";
import { useSelector } from "react-redux";
import { RootState } from "redux/configureAppStore";
import { LogPayload } from "typings";
import apis from "utils/apis";

export default function useAxiosApiWrapper<
  Data = unknown,
  P = unknown,
  ErrorData = unknown
>(api: AxiosApi<Data, P>) {
  const store = useSelector<RootState, RootState>((state) => state);
  const onrejected = useCallback(
    (error: AxiosError<ErrorData>) => {
      // send error log
      let logPayload: LogPayload = {
        function: "useAxiosApi",
        browserDescription: window.navigator.userAgent,
        jsonData: {
          action: api.name,
          data: error.response,
          store,
          deviceInfo: getDeviceInfo(),
        },
        level: "ERROR",
      };
      if (!error.response) {
        logPayload = {
          ...logPayload,
          message: error.message,
        };
      }
      apis.tools.createLog(logPayload);
    },
    [api.name, store]
  );
  const parameters = useAxiosApi<Data, P, ErrorData>(api, onrejected);
  return parameters;
}
